@@ -1,14 +1,14 @@
 chest<-hugin.domain()
 
 yn <- c("yes","no")
-add.node(chest,"asia",yn)
-add.node(chest,"tub",yn)
-add.node(chest,"smoke",yn)
-add.node(chest,"lung",yn)
-add.node(chest,"bronc",yn)
-add.node(chest,"either",yn)
-add.node(chest,"xray",yn)
-add.node(chest,"dysp",yn)
+add.node(chest,"asia",states=yn)
+add.node(chest,"tub",states=yn)
+add.node(chest,"smoke",states=yn)
+add.node(chest,"lung",states=yn)
+add.node(chest,"bronc",states=yn)
+add.node(chest,"either",states=yn)
+add.node(chest,"xray",states=yn)
+add.node(chest,"dysp",states=yn)
 
 add.edge(chest,"tub","asia")
 add.edge(chest,"lung","smoke")
@@ -30,15 +30,25 @@ chest
 
 compile(chest)
 
+summary(chest,jt=TRUE)
+
 get.normalization.constant(chest)
 
-
-set.finding(chest,"asia","yes")
-
+set.finding(chest,"smoke","no")
 set.finding(chest,"dysp","yes")
 
 get.normalization.constant(chest)
 
+get.belief(chest,'lung')
+get.belief(chest,'bronc')
+map.configurations(chest,get.nodes(chest),0.001)
+
+chest2<-clone.domain(chest)
+retract(chest2)
+summary(chest2)
+
+simulate(chest2,10)
+
 list.domains()
 
 
